/************************************************************
 **
 ** alias.c : alias API definitions
 **
 ** Copyright (c) 2009, Kyle York
 ** All rights reserved
 **
 ************************************************************/
#include <string.h>
#include "../libutils/mem.h"
#define ARRAY_DEFINE
#include "alias.h"

struct alias_ {
  char      *id;
  variable_t var;
};

alias_t alias_alloc(const char *id, variable_t var)
{
  alias_t dst;

  dst = ALIAS_NONE;
  if (id) {
    size_t sz;

    sz = 1 + strlen(id);
    dst = MALLOC(sizeof(*dst) + sz);
    if (dst) {
      dst->id  = (void *) (dst + 1);

      variable_lock(var);
      dst->var = var;
      memcpy(dst->id, id, sz);
    }
  }
  return dst;
}

void alias_free(alias_t alias)
{
  if (alias) {
    variable_release(alias->var);
    FREE(alias);
  }
}

const char *alias_id_get(const alias_t alias)
{
  return (alias) ? alias->id : 0;
}

variable_t  alias_var_get(const alias_t alias)
{
  return (alias) ? alias->var : VARIABLE_NONE;
}

